==> dcoraid-0.11.12-py3-none-any.whl: dcoraid/__main__.py <==
def main(splash=True):
    import logging
    import os
    import pkg_resources
    import platform
    import sys

    logging.basicConfig(
        level=logging.INFO,
        format="%(asctime)s %(levelname)s %(processName)s/%(threadName)s "
               + "in %(name)s: %(message)s",
        datefmt='%H:%M:%S')

    from PyQt5.QtWidgets import QApplication

    if platform.win32_ver()[0] == "7":
        # Use software OpenGL on Windows 7, because sometimes the
        # window content becomes plain white.
        # Not sure whether this actually works.
        from PyQt5.QtCore import Qt, QCoreApplication
        from PyQt5.QtGui import QGuiApplication
        QApplication.setAttribute(Qt.AA_UseSoftwareOpenGL)
        QCoreApplication.setAttribute(Qt.AA_UseSoftwareOpenGL)
        QGuiApplication.setAttribute(Qt.AA_UseSoftwareOpenGL)

    app = QApplication(sys.argv)
    imdir = pkg_resources.resource_filename("dcoraid", "img")

    if splash:
        from PyQt5.QtWidgets import QSplashScreen
        from PyQt5.QtGui import QPixmap
        from PyQt5.QtCore import QEventLoop
        splash_path = os.path.join(imdir, "splash.png")
        splash_pix = QPixmap(splash_path)
        splash = QSplashScreen(splash_pix)
        splash.setMask(splash_pix.mask())
        splash.show()
        app.processEvents(QEventLoop.AllEvents, 300)

    import warnings
    from requests.packages.urllib3.exceptions import SubjectAltNameWarning
    # Ignore SubjectAltNameWarning for certificates in medical branding,
    # because they will show up in the dclab-compress-warnings log.
    warnings.filterwarnings("ignore", category=SubjectAltNameWarning)

    from PyQt5 import QtCore, QtGui
    from .gui import DCORAid

    # Set Application Icon
    icon_path = os.path.join(imdir, "icon.png")
    app.setWindowIcon(QtGui.QIcon(icon_path))

    # Use dots as decimal separators
    QtCore.QLocale.setDefault(QtCore.QLocale(QtCore.QLocale.C))

    window = DCORAid()

    if splash:
        splash.finish(window)

    sys.exit(app.exec_())


if __name__ == "__main__":
    main()

==> dcoraid-0.16.4-py3-none-any.whl: dcoraid/__main__.py <==
def main(splash=True):
    from importlib import resources
    import logging
    import platform
    import sys

    from ._version import version

    logging.basicConfig(
        level=logging.DEBUG if version.count("post") else logging.INFO,
        format="%(asctime)s %(levelname)s %(processName)s/%(threadName)s "
               + "in %(name)s: %(message)s",
        datefmt='%H:%M:%S')

    from PyQt5.QtWidgets import QApplication

    if platform.win32_ver()[0] == "7":
        # Use software OpenGL on Windows 7, because sometimes the
        # window content becomes plain white.
        # Not sure whether this actually works.
        from PyQt5.QtCore import Qt, QCoreApplication
        from PyQt5.QtGui import QGuiApplication
        QApplication.setAttribute(Qt.AA_UseSoftwareOpenGL)
        QCoreApplication.setAttribute(Qt.AA_UseSoftwareOpenGL)
        QGuiApplication.setAttribute(Qt.AA_UseSoftwareOpenGL)

    app = QApplication(sys.argv)

    if splash:
        from PyQt5.QtWidgets import QSplashScreen
        from PyQt5.QtGui import QPixmap
        from PyQt5.QtCore import QEventLoop
        ref_splash = resources.files("dcoraid.img") / "splash.png"
        with resources.as_file(ref_splash) as splash_path:
            splash_pix = QPixmap(str(splash_path))
        splash = QSplashScreen(splash_pix)
        splash.setMask(splash_pix.mask())
        splash.show()
        app.processEvents(QEventLoop.AllEvents, 300)

    from PyQt5 import QtCore, QtGui
    from .gui import DCORAid

    # Set Application Icon
    ref_icon = resources.files("dcoraid.img") / "splash.png"
    with resources.as_file(ref_icon) as icon_path:
        app.setWindowIcon(QtGui.QIcon(str(icon_path)))

    # Use dots as decimal separators
    QtCore.QLocale.setDefault(QtCore.QLocale(QtCore.QLocale.C))

    window = DCORAid()

    if splash:
        splash.finish(window)

    sys.exit(app.exec_())


if __name__ == "__main__":
    main()
